package com.spider.quartz.mapper;

import java.util.List;
import com.spider.quartz.domain.JapanUnqualifiedGoodsZh;

/**
 * 日本不合格商品展示-翻译Mapper接口
 * 
 * @author ruoyi
 * @date 2025-12-05
 */
public interface JapanUnqualifiedGoodsZhMapper 
{
    /**
     * 查询日本不合格商品展示-翻译
     * 
     * @param id 日本不合格商品展示-翻译主键
     * @return 日本不合格商品展示-翻译
     */
    public JapanUnqualifiedGoodsZh selectJapanUnqualifiedGoodsZhById(Long id);

    /**
     * 查询日本不合格商品展示-翻译列表
     * 
     * @param japanUnqualifiedGoodsZh 日本不合格商品展示-翻译
     * @return 日本不合格商品展示-翻译集合
     */
    public List<JapanUnqualifiedGoodsZh> selectJapanUnqualifiedGoodsZhList(JapanUnqualifiedGoodsZh japanUnqualifiedGoodsZh);

    /**
     * 新增日本不合格商品展示-翻译
     * 
     * @param japanUnqualifiedGoodsZh 日本不合格商品展示-翻译
     * @return 结果
     */
    public int insertJapanUnqualifiedGoodsZh(JapanUnqualifiedGoodsZh japanUnqualifiedGoodsZh);

    /**
     * 修改日本不合格商品展示-翻译
     * 
     * @param japanUnqualifiedGoodsZh 日本不合格商品展示-翻译
     * @return 结果
     */
    public int updateJapanUnqualifiedGoodsZh(JapanUnqualifiedGoodsZh japanUnqualifiedGoodsZh);

    /**
     * 删除日本不合格商品展示-翻译
     * 
     * @param id 日本不合格商品展示-翻译主键
     * @return 结果
     */
    public int deleteJapanUnqualifiedGoodsZhById(Long id);

    /**
     * 批量删除日本不合格商品展示-翻译
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteJapanUnqualifiedGoodsZhByIds(Long[] ids);
}
